package sample;

import java.util.List;
import java.util.Vector;

import com.ibm.websphere.bo.BOFactory;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class CustomerServiceComponentImpl {
	/**
	 * Default constructor.
	 */
	public CustomerServiceComponentImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	/**
	 * Method generated to support implemention of operation
	 * "getCustomerInformation" defined for WSDL port type named
	 * "interface.CustomerService".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that its a complex type. Please refer to the WSDL
	 * Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject getCustomerInformation(String customerID) {
		System.out.println("Entering getCustomerInformation() with id: " + customerID);
		DataObject customer = null;
		if (customerID.equals("1111111")) {
			customer = initCustomer(customerID, "John", "Smith");
			addStock(customer, "IBM", 90);
			addStock(customer, "DELL", 100);
			addStock(customer, "SBC", 75);
		} else if (customerID.equals("2222222")) {
			customer = initCustomer(customerID, "Sally", "Johnson");
			addStock(customer, "IBM", 150);
			addStock(customer, "SBC", 300);
		} else if (customerID.equals("3333333")) {
			customer = initCustomer(customerID, "Billy", "Jones");
			addStock(customer, "IBM", 57);
			addStock(customer, "DELL", 12);
			addStock(customer, "SBC", 23);
		} else if (customerID.equals("4444444")) {
			customer = initCustomer(customerID, "Harold", "Green");
			addStock(customer, "IBM", 900);
		} else {
			customer = initCustomer(customerID, "unknown_customer", "old_backend");
			addStock(customer, "DELL", 1);
		}
		System.out.println("Exiting getCustomerInformation() with id: " + customerID);
		return customer;
	}

	/**
	 * Method generated to support implemention of operation
	 * "getCustomerExtendedInfo" defined for WSDL port type named
	 * "interface.CustomerServiceExtended".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a
	 * parameter type conveys that its a complex type. Please refer to the WSDL
	 * Definition for more information on the type of input, output and
	 * fault(s).
	 */
	public DataObject getCustomerExtendedInfo(String customerID,
			String portfolioRequested) {
		System.out.println("Entering getCustomerExtendedInfo() with id: " + customerID);
		DataObject customer = null;
		if (customerID.equals("5555555")) {
			customer = initCustomerExtended(customerID, "Harry", "Wilson", "standard", portfolioRequested);
			addStock(customer, "IBM", 45);
			addStock(customer, "DELL", 300);
			addStock(customer, "SBC", 270);
		} else if (customerID.equals("6666666")) {
			customer = initCustomerExtended(customerID, "Deborah", "Watson", "premium", portfolioRequested);
			addStock(customer, "IBM", 250);
			addStock(customer, "DELL", 825);
			addStock(customer, "SBC", 450);
		} else if (customerID.equals("7777777")) {
			customer = initCustomerExtended(customerID, "Katherine", "Anderson", "standard", portfolioRequested);
			addStock(customer, "IBM", 14);
			addStock(customer, "DELL", 43);
		} else if (customerID.equals("8888888")) {
			customer = initCustomerExtended(customerID, "Mary Beth", "O'Donald", "premium", portfolioRequested);
			addStock(customer, "IBM", 160);
			addStock(customer, "DELL", 1030);
			addStock(customer, "SBC", 710);
		} else if (customerID.equals("9999999")) {
			customer = initCustomerExtended(customerID, "Joseph", "Baker", "standard", portfolioRequested);
			addStock(customer, "SBC", 73);
		} else {
			customer = initCustomerExtended(customerID, "unknown_customer", "new_backend", "", "");
			addStock(customer, "SBC", 1);
		}
		System.out.println("Exiting getCustomerExtendedInfo() with id: " + customerID);
		return customer;
	}

	private DataObject initCustomer(String customerID, String firstName,
			String lastName) {
		return initDataObject("Customer", customerID, firstName, lastName, "",
				"");
	}

	private DataObject initCustomerExtended(String customerID,
			String firstName, String lastName, String serviceLevel,
			String portfolioID) {
		return initDataObject("CustomerExtended", customerID, firstName,
				lastName, serviceLevel, portfolioID);
	}

	/**
	 * Initializes a Customer or CustomerExtended DataObject according to the
	 * parameter values passed.
	 */
	private DataObject initDataObject(String type, String customerID,
			String firstName, String lastName, String serviceLevel,
			String portfolioID) {

		// Create the DataObject of requested type
		BOFactory bof = (BOFactory) ServiceManager.INSTANCE
				.locateService("com/ibm/websphere/bo/BOFactory");
		DataObject customer;
		if (type.equals("Customer"))
			customer = bof.create("http://PortfolioManager", type);
		else
			customer = bof.create("http://PortfolioLibrary", type);

		// Initialize the DataObject with passed values
		customer.setString("customerID", customerID);
		customer.setString("firstName", firstName);
		customer.setString("lastName", lastName);
		if (type.equals("CustomerExtended")) {
			customer.setString("serviceLevel", serviceLevel);
			customer.setString("portfolioID", portfolioID);
		}

		// Setup the empty list of Stocks
		List list = new Vector();
		customer.setList("stocks", list);

		return customer;
	}

	/**
	 * Create a Stock DataObject with symbol and number of shares and add it to
	 * the list
	 */
	private void addStock(DataObject customer, String symbol, int shares) {
		// Create the Stock DataObject
		BOFactory bof = (BOFactory) ServiceManager.INSTANCE
				.locateService("com/ibm/websphere/bo/BOFactory");
		DataObject stock = bof.create("http://PortfolioManager", "Stock");

		// Initialize the Stock DataObject with passed values
		stock.setString("symbol", symbol);
		stock.setInt("numberOfShares", shares);

		// Add the Stock DataObject to the customers list of stocks
		customer.getList("stocks").add(stock);

		return;
	}
}